@@ -1,6 +1,6 @@
 /*
  *  wysidocbookdaemon -- daemon for wysi docbook XML 
- *  Copyright (C) 2003 Junichi Uekawa
+ *  Copyright (C) 2003,2005 Junichi Uekawa
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ char * currentfile = NULL;
 char * temporary_filename = NULL;
 
 /** the stylesheet */
-char * xsltstylesheet = "/usr/share/sgml/docbook/stylesheet/xsl/ldp/ldp-html.xsl";
+char * xsltstylesheet = "/usr/share/xml/docbook/stylesheet/ldp/html/tldp-one-page.xsl";
 
 /** the optional string #xxxx to pass to mozilla URL */
 char * optional = NULL;
